#!/usr/bin/env python
# -*- encoding: utf-8 -*-
#
#  Copyright 2014 Canonical Ltd.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation; version 3.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

# Borrowed the following helper class from
# lp:address-book-service/examples/contacts.py

import dbus

DBUS_IFACE_ADD_BOOK = 'com.canonical.pim.AddressBook'
DBUS_IFACE_ADD_BOOKVIEW = 'com.canonical.pim.AddressBookView'

TEL_WORK_TEMPLATE = """
TEL;TYPE=WORK,VOICE;PID=1.1:{tel_work}"""

VCARD_TEMPLATE = """BEGIN:VCARD
VERSION:3.0
N:{name}
FN:{f_name}
TEL;TYPE=HOME,VOICE;PID=1.1:{tel_home}{tel_work}
END:VCARD
"""


class AddressBook(object):

    def __init__(self):
        self.bus = dbus.SessionBus()
        self.addr = self.bus.get_object('com.canonical.pim',
                                        '/com/canonical/pim/AddressBook')
        self.addr_iface = dbus.Interface(self.addr,
                                         dbus_interface=DBUS_IFACE_ADD_BOOK)

    def create_contact(self,
                       name,
                       f_name=None,
                       tel_home=None,
                       tel_work=None,
                       email=None):
        """Create a contact in address-book via dbus interface.

        NOTE that if only one phone number is specified, it must be tel_home.

        :param name: name of the contact, e.g. 'Lincoln;Abraham'
        :param f_name: formatted name of the contact, e.g. 'Abraham Lincoln'
        :param tel_home: telephone number string, e.g. '92340981'
        :param tel_work: telephone number string, e.g. '23984719'
        :param email: e-mail address string, e.g. 'abe@whitehouse.gov'
        """
        contact_dict = {
            'name': name,
            'f_name': f_name if f_name else '',
            'tel_home': tel_home if tel_home else '',
            'tel_work': TEL_WORK_TEMPLATE.format(
                tel_work=tel_work) if tel_work else '',
            'email': email if email else ''
        }
        vcard = VCARD_TEMPLATE.format(**contact_dict)
        return self.addr_iface.createContact(vcard, "")
