# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# Copyright 2014 Canonical
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

"""Utilities for the evolution contacts db."""

import os
import subprocess
import tempfile


def backup_evolution_contacts_db(backup_filepath=None):
    """Back up the existing evolution contacts db to a file.

    :param backup_filepath: file to which to write, if None make tmpfile.
    :returns: backup filepath used.
    """
    if backup_filepath is None:
        backup_filepath = tempfile.mktemp(suffix=".syncevolution")
    subprocess.call([
        'syncevolution',
        '--export',
        backup_filepath,
        'backend=evolution-contacts',
    ])
    return backup_filepath


def restore_evolution_contacts_db(backup_filepath):
    """Restore the evolution contacts db from the backup.

    :param backup_filepath: file from which to restore.
    """
    # NOTE restoring from empty file creates a phantom contact
    if os.path.getsize(backup_filepath) > 0:
        subprocess.call([
            'syncevolution',
            '--import',
            backup_filepath,
            'backend=evolution-contacts'
        ])


def wipe_evolution_contacts_db():
    """Wipe the existing evolution contacts db clean of contacts."""
    subprocess.call([
        'syncevolution',
        '--delete-items',
        'backend=evolution-contacts',
        '--luids',
        '*',
    ])
